import { stackedAreaChart } from './stackedAreaChart';
import { colorLegend } from './colorLegend';

const svg = d3.select(document.body).append('svg');

// defining the labels 
var parseRow = d => {
  d.Year = new Date(d.Year);
  d.Green = d.Green;
  d.Loggerhead = d.Loggerhead;
  d.Hawksbill = d.Hawksbill;
  return d;
};


// Generating legend circles
svg.append("circle").attr("cx",700).attr("cy",130).attr("r", 6).style("fill", "#EE750C")
svg.append("circle").attr("cx",700).attr("cy",160).attr("r", 6).style("fill", "#A770B9")
svg.append("circle").attr("cx",700).attr("cy",190).attr("r", 6).style("fill", "green")

// Generating legend circles
svg.append("text").attr("x", 720).attr("y", 130).text("Loggerhead Turtle").style("font-size", "15px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 720).attr("y", 160).text("Hawksbill Turtle").style("font-size", "15px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 720).attr("y", 190).text("Green Turtle").style("font-size", "15px").attr("alignment-baseline","middle")

//importing csv data and parsing it to sue it on the charts
d3.csv('data.csv', parseRow, data => {
 
  data = data.filter(d => d.Year > new Date("1900"));
  const render = () => {
    const width = document.body.clientWidth;
    const height = document.body.clientHeight;
    
    svg.attr('width', width).attr('height', height);
    
    let g = svg.selectAll('g').data([null]);
    g = g.enter().append('g').merge(g);
    
    //Passing the parameters to stackedAreaChart module
    stackedAreaChart(g, {
      data,
      keys: ["Green", "Loggerhead", "Hawksbill"],
      width,
      height,
      xValue: d => d.Year,
      xAxisTitle: 'Year',
      colorScale: d3.scaleOrdinal(d3.schemeDark2),
      margin: { top: 90, right: 70, bottom: 50, left: 100 },
      yAxisTitle: 'Sea Turtle Population',
      yAxisTitleOffset: -60
                  
    });
    
    let legend = d3.legendColor()
        .scale(color)
        .title("USA States");
   
    // adding colors to the area using the pre-defined colorLengend module
    svg.append('g')
    .attr('transform', `translate(700,110)`)
    .call(colorLegend, {
      colorScale,
      circleRadius: 10,
      spacing: 55,
      textOffset: 15
    });
  };
  render();
  
  //plot resizes when window is resized
  window.addEventListener('resize', render);
});